@@ -18,6 +18,7 @@ pub fn get_string(q: &str) -> String {
     }
 }
 
+// make the type same as varible
 pub fn get_int(q: &str) -> i32 {
     loop {
         print!("{}", q);
@@ -35,3 +36,20 @@ pub fn get_int(q: &str) -> i32 {
     }
 }
 
+pub fn get_float(q: &str) -> f64 {
+    loop {
+        print!("{}", q);
+        io::stdout().flush().unwrap();
+    
+        let mut str = String::new();
+    
+        io::stdin().read_line(&mut str).ok();
+        let num = str.trim().parse();
+        let num = match num {
+            Ok(n) => n,
+            Err(_) => continue,
+        };
+        return num
+    }
+}
+
